==> qtjambi-webenginecore-6.5.4-sources.jar: io/qt/webengine/core/QWebEngineNotification.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Encapsulates the data of an HTML5 web notification</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginenotification.html">QWebEngineNotification</a></code></p>
 */
public final class QWebEngineNotification extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNotification.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#closed">QWebEngineNotification::<wbr/>closed()</a></code></p>
     */
    public final @NonNull Signal0 closed = new Signal0();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#click">QWebEngineNotification::<wbr/>click()const</a></code></p>
     */
    public final void click(){
        click_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void click_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#close">QWebEngineNotification::<wbr/>close()const</a></code></p>
     */
    public final void close(){
        close_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void close_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#direction-prop">QWebEngineNotification::<wbr/>direction()const</a></code></p>
     */
    @QtPropertyReader(name="direction")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.Qt.@NonNull LayoutDirection direction(){
        return io.qt.core.Qt.LayoutDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#icon">QWebEngineNotification::<wbr/>icon()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.gui.@NonNull QImage icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.gui.QImage icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#language-prop">QWebEngineNotification::<wbr/>language()const</a></code></p>
     */
    @QtPropertyReader(name="language")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String language(){
        return language_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String language_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#matches">QWebEngineNotification::<wbr/>matches(const QWebEngineNotification*)const</a></code></p>
     */
    @QtUninvokable
    public final boolean matches(io.qt.webengine.core.@Nullable QWebEngineNotification other){
        return matches_native_const_QWebEngineNotification_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean matches_native_const_QWebEngineNotification_ptr_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#message-prop">QWebEngineNotification::<wbr/>message()const</a></code></p>
     */
    @QtPropertyReader(name="message")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#origin-prop">QWebEngineNotification::<wbr/>origin()const</a></code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#show">QWebEngineNotification::<wbr/>show()const</a></code></p>
     */
    public final void show(){
        show_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void show_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#tag-prop">QWebEngineNotification::<wbr/>tag()const</a></code></p>
     */
    @QtPropertyReader(name="tag")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String tag(){
        return tag_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String tag_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#title-prop">QWebEngineNotification::<wbr/>title()const</a></code></p>
     */
    @QtPropertyReader(name="title")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineNotification(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #direction()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.Qt.@NonNull LayoutDirection getDirection() {
        return direction();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #language()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getLanguage() {
        return language();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #message()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getMessage() {
        return message();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #tag()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getTag() {
        return tag();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #title()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getTitle() {
        return title();
    }
}

==> qtjambi-webenginecore-6.5.7-sources.jar: io/qt/webengine/core/QWebEngineNotification.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Encapsulates the data of an HTML5 web notification</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qwebenginenotification.html">QWebEngineNotification</a></code></p>
 */
public final class QWebEngineNotification extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNotification.class);
    

    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#closed">QWebEngineNotification::<wbr/>closed()</a></code></p>
     */
    public final @NonNull Signal0 closed = new Signal0();
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#click">QWebEngineNotification::<wbr/>click()const</a></code></p>
     */
    public final void click(){
        click_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void click_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#close">QWebEngineNotification::<wbr/>close()const</a></code></p>
     */
    public final void close(){
        close_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void close_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#direction-prop">QWebEngineNotification::<wbr/>direction()const</a></code></p>
     */
    @QtPropertyReader(name="direction")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.Qt.@NonNull LayoutDirection direction(){
        return io.qt.core.Qt.LayoutDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#icon">QWebEngineNotification::<wbr/>icon()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.gui.@NonNull QImage icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.gui.QImage icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#language-prop">QWebEngineNotification::<wbr/>language()const</a></code></p>
     */
    @QtPropertyReader(name="language")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String language(){
        return language_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String language_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#matches">QWebEngineNotification::<wbr/>matches(const QWebEngineNotification*)const</a></code></p>
     */
    @QtUninvokable
    public final boolean matches(io.qt.webengine.core.@Nullable QWebEngineNotification other){
        return matches_native_const_QWebEngineNotification_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native boolean matches_native_const_QWebEngineNotification_ptr_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#message-prop">QWebEngineNotification::<wbr/>message()const</a></code></p>
     */
    @QtPropertyReader(name="message")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#origin-prop">QWebEngineNotification::<wbr/>origin()const</a></code></p>
     */
    @QtPropertyReader(name="origin")
    @QtPropertyConstant
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#show">QWebEngineNotification::<wbr/>show()const</a></code></p>
     */
    public final void show(){
        show_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void show_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#tag-prop">QWebEngineNotification::<wbr/>tag()const</a></code></p>
     */
    @QtPropertyReader(name="tag")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String tag(){
        return tag_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String tag_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qwebenginenotification.html#title-prop">QWebEngineNotification::<wbr/>title()const</a></code></p>
     */
    @QtPropertyReader(name="title")
    @QtPropertyConstant
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    private QWebEngineNotification(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #direction()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.Qt.@NonNull LayoutDirection getDirection() {
        return direction();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #language()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getLanguage() {
        return language();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #message()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getMessage() {
        return message();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #origin()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl getOrigin() {
        return origin();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #tag()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getTag() {
        return tag();
    }
    
    /**
     * @hidden
     * <p>Kotlin property getter. In Java use {@link #title()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final java.lang.@NonNull String getTitle() {
        return title();
    }
}
